@@ -16,15 +16,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-import chess
 import collections
+import itertools
 import mmap
 import os
-import struct
-import sys
-import threading
 import re
+import struct
+import threading
 
+import chess
 
 UINT64_BE = struct.Struct(">Q")
 UINT32 = struct.Struct("<I")
@@ -377,7 +377,7 @@ def is_table_name(name):
     return len(name) <= 7 + 1 and TABLENAME_REGEX.match(name) and normalize_tablename(name) == name
 
 
-def tablenames(one_king=True, piece_count=6):
+def tablenames(*, one_king=True, piece_count=6):
     first = "K" if one_king else "P"
 
     targets = []
@@ -392,7 +392,7 @@ def tablenames(one_king=True, piece_count=6):
     return all_dependencies(targets, one_king=one_king)
 
 
-def normalize_tablename(name, mirror=False):
+def normalize_tablename(name, *, mirror=False):
     w, b = name.split("v", 1)
     w = "".join(sorted(w, key=PCHR.index))
     b = "".join(sorted(b, key=PCHR.index))
@@ -402,7 +402,7 @@ def normalize_tablename(name, mirror=False):
         return w + "v" + b
 
 
-def _dependencies(target, one_king=True):
+def _dependencies(target, *, one_king=True):
     w, b = target.split("v", 1)
 
     for p in PCHR:
@@ -422,18 +422,18 @@ def _dependencies(target, one_king=True):
             yield normalize_tablename(w + "v" + b.replace(p, "", 1))
 
 
-def dependencies(target, one_king=True):
+def dependencies(target, *, one_king=True):
     closed = set()
     if one_king:
         closed.add("KvK")
 
-    for dependency in _dependencies(target, one_king):
+    for dependency in _dependencies(target, one_king=one_king):
         if dependency not in closed and len(dependency) > 2:
             yield dependency
             closed.add(dependency)
 
 
-def all_dependencies(targets, one_king=True):
+def all_dependencies(targets, *, one_king=True):
     closed = set()
     if one_king:
         closed.add("KvK")
@@ -448,10 +448,10 @@ def all_dependencies(targets, one_king=True):
         yield name
         closed.add(name)
 
-        open_list.extend(_dependencies(name, one_king))
+        open_list.extend(_dependencies(name, one_king=one_king))
 
 
-def calc_key(board, mirror=False):
+def calc_key(board, *, mirror=False):
     w = board.occupied_co[chess.WHITE ^ mirror]
     b = board.occupied_co[chess.BLACK ^ mirror]
 
@@ -472,7 +472,7 @@ def calc_key(board, mirror=False):
     ])
 
 
-def recalc_key(pieces, mirror=False):
+def recalc_key(pieces, *, mirror=False):
     # Some endgames are stored with a different key than their filename
     # indicates: http://talkchess.com/forum/viewtopic.php?p=695509#695509
 
@@ -516,7 +516,7 @@ class MissingTableError(KeyError):
     pass
 
 
-class PairsData(object):
+class PairsData:
     def __init__(self):
         self.indextable = None
         self.sizetable = None
@@ -530,7 +530,7 @@ class PairsData(object):
         self.base = None
 
 
-class PawnFileData(object):
+class PawnFileData:
     def __init__(self):
         self.precomp = {}
         self.factor = {}
@@ -538,7 +538,7 @@ class PawnFileData(object):
         self.norm = {}
 
 
-class PawnFileDataDtz(object):
+class PawnFileDataDtz:
     def __init__(self):
         self.precomp = None
         self.factor = None
@@ -546,9 +546,9 @@ class PawnFileDataDtz(object):
         self.norm = None
 
 
-class Table(object):
+class Table:
 
-    def __init__(self, path, variant=chess.Board):
+    def __init__(self, path, *, variant=chess.Board):
         self.path = path
         self.variant = variant
 
@@ -603,26 +603,17 @@ class Table(object):
         if self.data is None:
             self.data = mmap.mmap(self.fd, 0, access=mmap.ACCESS_READ)
 
-            # Micro optimizations for read_uint8.
-            if sys.version_info >= (3, ):
-                self.read_uint8 = self.data.__getitem__
-            else:
-                def read_uint8(data_ptr):
-                    return ord(self.data[data_ptr])
-
-                self.read_uint8 = read_uint8
-
     def check_magic(self, magic):
-        return all(self.read_uint8(i) == m for i, m in enumerate(magic))
+        return self.data[:min(len(self.data), len(magic))] == magic
 
     def setup_pairs(self, data_ptr, tb_size, size_idx, wdl):
         d = PairsData()
 
-        self._flags = self.read_uint8(data_ptr)
-        if self.read_uint8(data_ptr) & 0x80:
+        self._flags = self.data[data_ptr]
+        if self.data[data_ptr] & 0x80:
             d.idxbits = 0
             if wdl:
-                d.min_len = self.read_uint8(data_ptr + 1)
+                d.min_len = self.data[data_ptr + 1]
             else:
                 # http://www.talkchess.com/forum/viewtopic.php?p=698093#698093
                 d.min_len = 1 if self.variant.captures_compulsory else 0
@@ -632,13 +623,13 @@ class Table(object):
             self.size[size_idx + 2] = 0
             return d
 
-        d.blocksize = self.read_uint8(data_ptr + 1)
-        d.idxbits = self.read_uint8(data_ptr + 2)
+        d.blocksize = self.data[data_ptr + 1]
+        d.idxbits = self.data[data_ptr + 2]
 
         real_num_blocks = self.read_uint32(data_ptr + 4)
-        num_blocks = real_num_blocks + self.read_uint8(data_ptr + 3)
-        max_len = self.read_uint8(data_ptr + 8)
-        min_len = self.read_uint8(data_ptr + 9)
+        num_blocks = real_num_blocks + self.data[data_ptr + 3]
+        max_len = self.data[data_ptr + 8]
+        min_len = self.data[data_ptr + 9]
         h = max_len - min_len + 1
         num_syms = self.read_uint16(data_ptr + 10 + 2 * h)
 
@@ -752,11 +743,11 @@ class Table(object):
 
     def calc_symlen(self, d, s, tmp):
         w = d.sympat + 3 * s
-        s2 = (self.read_uint8(w + 2) << 4) | (self.read_uint8(w + 1) >> 4)
+        s2 = (self.data[w + 2] << 4) | (self.data[w + 1] >> 4)
         if s2 == 0x0fff:
             d.symlen[s] = 0
         else:
-            s1 = ((self.read_uint8(w + 1) & 0xf) << 8) | self.read_uint8(w)
+            s1 = ((self.data[w + 1] & 0xf) << 8) | self.data[w]
             if not tmp[s1]:
                 self.calc_symlen(d, s1, tmp)
             if not tmp[s2]:
@@ -992,18 +983,18 @@ class Table(object):
         sympat = d.sympat
         while d.symlen[symlen_idx + sym]:
             w = sympat + 3 * sym
-            s1 = ((self.read_uint8(w + 1) & 0xf) << 8) | self.read_uint8(w)
+            s1 = ((self.data[w + 1] & 0xf) << 8) | self.data[w]
             if litidx < d.symlen[symlen_idx + s1] + 1:
                 sym = s1
             else:
                 litidx -= d.symlen[symlen_idx + s1] + 1
-                sym = (self.read_uint8(w + 2) << 4) | (self.read_uint8(w + 1) >> 4)
+                sym = (self.data[w + 2] << 4) | (self.data[w + 1] >> 4)
 
         w = sympat + 3 * sym
         if isinstance(self, DtzTable):
-            return ((self.read_uint8(w + 1) & 0x0f) << 8) | self.read_uint8(w)
+            return ((self.data[w + 1] & 0x0f) << 8) | self.data[w]
         else:
-            return self.read_uint8(w)
+            return self.data[w]
 
     def read_uint64_be(self, data_ptr):
         return UINT64_BE.unpack_from(self.data, data_ptr)[0]
@@ -1046,9 +1037,8 @@ class WdlTable(Table):
             if self.initialized:
                 return
 
-            assert self.check_magic(self.variant.tbw_magic) or (
-                not self.has_pawns and self.variant.pawnless_tbw_magic and
-                self.check_magic(self.variant.pawnless_tbw_magic))
+            if not self.check_magic(self.variant.tbw_magic) and (self.has_pawns or self.variant.pawnless_tbw_magic is None or not self.check_magic(self.variant.pawnless_tbw_magic)):
+                raise IOError("invalid magic header: ensure {} is a valid syzygy tablebase file".format(self.path))
 
             self.tb_size = [0 for _ in range(8)]
             self.size = [0 for _ in range(8 * 3)]
@@ -1070,8 +1060,8 @@ class WdlTable(Table):
             self._flags = None
             self.flags = None
 
-            split = self.read_uint8(4) & 0x01
-            files = 4 if self.read_uint8(4) & 0x02 else 1
+            split = self.data[4] & 0x01
+            files = 4 if self.data[4] & 0x02 else 1
 
             data_ptr = 5
 
@@ -1152,30 +1142,30 @@ class WdlTable(Table):
 
     def setup_pieces_pawn(self, p_data, p_tb_size, f):
         j = 1 + int(self.pawns[1] > 0)
-        order = self.read_uint8(p_data) & 0x0f
-        order2 = self.read_uint8(p_data + 1) & 0x0f if self.pawns[1] else 0x0f
-        self.files[f].pieces[0] = [self.read_uint8(p_data + i + j) & 0x0f for i in range(self.num)]
+        order = self.data[p_data] & 0x0f
+        order2 = self.data[p_data + 1] & 0x0f if self.pawns[1] else 0x0f
+        self.files[f].pieces[0] = [self.data[p_data + i + j] & 0x0f for i in range(self.num)]
         self.files[f].norm[0] = [0 for _ in range(self.num)]
         self.set_norm_pawn(self.files[f].norm[0], self.files[f].pieces[0])
         self.files[f].factor[0] = [0 for _ in range(TBPIECES)]
         self.tb_size[p_tb_size] = self.calc_factors_pawn(self.files[f].factor[0], order, order2, self.files[f].norm[0], f)
 
-        order = self.read_uint8(p_data) >> 4
-        order2 = self.read_uint8(p_data + 1) >> 4 if self.pawns[1] else 0x0f
-        self.files[f].pieces[1] = [self.read_uint8(p_data + i + j) >> 4 for i in range(self.num)]
+        order = self.data[p_data] >> 4
+        order2 = self.data[p_data + 1] >> 4 if self.pawns[1] else 0x0f
+        self.files[f].pieces[1] = [self.data[p_data + i + j] >> 4 for i in range(self.num)]
         self.files[f].norm[1] = [0 for _ in range(self.num)]
         self.set_norm_pawn(self.files[f].norm[1], self.files[f].pieces[1])
         self.files[f].factor[1] = [0 for _ in range(TBPIECES)]
         self.tb_size[p_tb_size + 1] = self.calc_factors_pawn(self.files[f].factor[1], order, order2, self.files[f].norm[1], f)
 
     def setup_pieces_piece(self, p_data):
-        self.pieces[0] = [self.read_uint8(p_data + i + 1) & 0x0f for i in range(self.num)]
-        order = self.read_uint8(p_data) & 0x0f
+        self.pieces[0] = [self.data[p_data + i + 1] & 0x0f for i in range(self.num)]
+        order = self.data[p_data] & 0x0f
         self.set_norm_piece(self.norm[0], self.pieces[0])
         self.tb_size[0] = self.calc_factors_piece(self.factor[0], order, self.norm[0])
 
-        self.pieces[1] = [self.read_uint8(p_data + i + 1) >> 4 for i in range(self.num)]
-        order = self.read_uint8(p_data) >> 4
+        self.pieces[1] = [self.data[p_data + i + 1] >> 4 for i in range(self.num)]
+        order = self.data[p_data] >> 4
         self.set_norm_piece(self.norm[1], self.pieces[1])
         self.tb_size[1] = self.calc_factors_piece(self.factor[1], order, self.norm[1])
 
@@ -1241,7 +1231,7 @@ class WdlTable(Table):
 
     def close(self):
         with self.lock:
-            super(WdlTable, self).close()
+            super().close()
 
 
 class DtzTable(Table):
@@ -1253,9 +1243,8 @@ class DtzTable(Table):
             if self.initialized:
                 return
 
-            assert self.check_magic(self.variant.tbz_magic) or (
-                not self.has_pawns and self.variant.pawnless_tbz_magic and
-                self.check_magic(self.variant.pawnless_tbz_magic))
+            if not self.check_magic(self.variant.tbz_magic) and (self.has_pawns or self.variant.pawnless_tbz_magic is None or not self.check_magic(self.variant.pawnless_tbz_magic)):
+                raise IOError("invalid magic header: ensure {} is a valid syzygy tablebase file".format(self.path))
 
             self.factor = [0 for _ in range(TBPIECES)]
             self.norm = [0 for _ in range(self.num)]
@@ -1263,7 +1252,7 @@ class DtzTable(Table):
             self.size = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
             self.files = [PawnFileDataDtz() for f in range(4)]
 
-            files = 4 if self.read_uint8(4) & 0x02 else 1
+            files = 4 if self.data[4] & 0x02 else 1
 
             p_data = 5
 
@@ -1282,7 +1271,7 @@ class DtzTable(Table):
                     if not self.flags & 16:
                         for i in range(4):
                             self.map_idx[i] = p_data + 1 - self.p_map
-                            p_data += 1 + self.read_uint8(p_data)
+                            p_data += 1 + self.data[p_data]
                     else:
                         for i in range(4):
                             self.map_idx[i] = (p_data + 2 - self.p_map) // 2
@@ -1322,7 +1311,7 @@ class DtzTable(Table):
                         if not self.flags[f] & 16:
                             for _ in range(4):
                                 self.map_idx[-1].append(p_data + 1 - self.p_map)
-                                p_data += 1 + self.read_uint8(p_data)
+                                p_data += 1 + self.data[p_data]
                         else:
                             p_data += p_data & 0x01
                             for _ in range(4):
@@ -1384,7 +1373,7 @@ class DtzTable(Table):
 
             if self.flags & 2:
                 if not self.flags & 16:
-                    res = self.read_uint8(self.p_map + self.map_idx[WDL_TO_MAP[wdl + 2]] + res)
+                    res = self.data[self.p_map + self.map_idx[WDL_TO_MAP[wdl + 2]] + res]
                 else:
                     res = self.read_uint16(self.p_map + 2 * (self.map_idx[WDL_TO_MAP[wdl + 2]] + res))
 
@@ -1420,7 +1409,7 @@ class DtzTable(Table):
 
             if self.flags[f] & 2:
                 if not self.flags[f] & 16:
-                    res = self.read_uint8(self.p_map + self.map_idx[f][WDL_TO_MAP[wdl + 2]] + res)
+                    res = self.data[self.p_map + self.map_idx[f][WDL_TO_MAP[wdl + 2]] + res]
                 else:
                     res = self.read_uint16(self.p_map + 2 * (self.map_idx[f][WDL_TO_MAP[wdl + 2]] + res))
 
@@ -1430,16 +1419,16 @@ class DtzTable(Table):
         return res, 1
 
     def setup_pieces_piece_dtz(self, p_data, p_tb_size):
-        self.pieces = [self.read_uint8(p_data + i + 1) & 0x0f for i in range(self.num)]
-        order = self.read_uint8(p_data) & 0x0f
+        self.pieces = [self.data[p_data + i + 1] & 0x0f for i in range(self.num)]
+        order = self.data[p_data] & 0x0f
         self.set_norm_piece(self.norm, self.pieces)
         self.tb_size[p_tb_size] = self.calc_factors_piece(self.factor, order, self.norm)
 
     def setup_pieces_pawn_dtz(self, p_data, p_tb_size, f):
         j = 1 + int(self.pawns[1] > 0)
-        order = self.read_uint8(p_data) & 0x0f
-        order2 = self.read_uint8(p_data + 1) & 0x0f if self.pawns[1] else 0x0f
-        self.files[f].pieces = [self.read_uint8(p_data + i + j) & 0x0f for i in range(self.num)]
+        order = self.data[p_data] & 0x0f
+        order2 = self.data[p_data + 1] & 0x0f if self.pawns[1] else 0x0f
+        self.files[f].pieces = [self.data[p_data + i + j] & 0x0f for i in range(self.num)]
 
         self.files[f].norm = [0 for _ in range(self.num)]
         self.set_norm_pawn(self.files[f].norm, self.files[f].pieces)
@@ -1449,10 +1438,10 @@ class DtzTable(Table):
 
     def close(self):
         with self.lock:
-            super(DtzTable, self).close()
+            super().close()
 
 
-class Tablebases(object):
+class Tablebase:
     """
     Manages a collection of tablebase files for probing.
 
@@ -1460,7 +1449,7 @@ class Tablebases(object):
     descriptors at any given time. The least recently used tables are closed,
     if nescessary.
     """
-    def __init__(self, max_fds=128, VariantBoard=chess.Board):
+    def __init__(self, *, max_fds=128, VariantBoard=chess.Board):
         self.variant = VariantBoard
 
         self.max_fds = max_fds
@@ -1483,7 +1472,7 @@ class Tablebases(object):
                 self.lru.pop().close()
 
     def _open_table(self, hashtable, Table, path):
-        table = Table(path, self.variant)
+        table = Table(path, variant=self.variant)
 
         if table.key in hashtable:
             hashtable[table.key].close()
@@ -1492,7 +1481,7 @@ class Tablebases(object):
         hashtable[table.mirrored_key] = table
         return 1
 
-    def open_directory(self, directory, load_wdl=True, load_dtz=True):
+    def add_directory(self, directory, *, load_wdl=True, load_dtz=True):
         """
         Loads tables from a directory.
 
@@ -1500,7 +1489,7 @@ class Tablebases(object):
         (e.g. WDL files like ``KQvKN.rtbw`` and DTZ files like ``KRBvK.rtbz``)
         are loaded.
 
-        Returns the number of tablebases files that were found.
+        Returns the number of table files that were found.
         """
         num = 0
         directory = os.path.abspath(directory)
@@ -1524,6 +1513,9 @@ class Tablebases(object):
 
         return num
 
+    # TODO: Deprecated
+    open_directory = add_directory
+
     def probe_wdl_table(self, board):
         # Test for variant end.
         if board.is_variant_win():
@@ -1648,15 +1640,16 @@ class Tablebases(object):
         >>> import chess
         >>> import chess.syzygy
         >>>
-        >>> with chess.syzygy.open_tablebases("data/syzygy/regular") as tablebases:
+        >>> with chess.syzygy.open_tablebase("data/syzygy/regular") as tablebase:
         ...     board = chess.Board("8/2K5/4B3/3N4/8/8/4k3/8 b - - 0 1")
-        ...     print(tablebases.probe_wdl(board))
+        ...     print(tablebase.probe_wdl(board))
         ...
         -2
 
         :raises: :exc:`KeyError` (or specifically
-            :exc:`chess.syzygy.MissingTableError`) if the probe fails. Use
-            :func:`~chess.syzygy.Tablebases.get_wdl()` if you prefer to get
+            :exc:`chess.syzygy.MissingTableError`) if the position could not
+            be found in the tablebase. Use
+            :func:`~chess.syzygy.Tablebase.get_wdl()` if you prefer to get
             ``None`` instead of an exception.
         """
         # Positions with castling rights are not in the tablebase.
@@ -1839,9 +1832,9 @@ class Tablebases(object):
         >>> import chess
         >>> import chess.syzygy
         >>>
-        >>> with chess.syzygy.open_tablebases("data/syzygy/regular") as tablebases:
+        >>> with chess.syzygy.open_tablebase("data/syzygy/regular") as tablebase:
         ...     board = chess.Board("8/2K5/4B3/3N4/8/8/4k3/8 b - - 0 1")
-        ...     print(tablebases.probe_dtz(board))
+        ...     print(tablebase.probe_dtz(board))
         ...
         -53
 
@@ -1849,8 +1842,9 @@ class Tablebases(object):
         if *board* objects are not modified during probing.
 
         :raises: :exc:`KeyError` (or specifically
-            :exc:`chess.syzygy.MissingTableError`) if the probe fails. Use
-            :func:`~chess.syzygy.Tablebases.get_dtz()` if you prefer to get
+            :exc:`chess.syzygy.MissingTableError`) if the position could not
+            be found in the tablebase. Use
+            :func:`~chess.syzygy.Tablebase.get_dtz()` if you prefer to get
             ``None`` instead of an exception.
         """
         v = self.probe_dtz_no_ep(board)
@@ -1919,10 +1913,10 @@ class Tablebases(object):
         self.close()
 
 
-def open_tablebases(directory, load_wdl=True, load_dtz=True, max_fds=128, VariantBoard=chess.Board):
+def open_tablebase(directory, *, load_wdl=True, load_dtz=True, max_fds=128, VariantBoard=chess.Board):
     """
-    Opens a collection of tablebases for probing. See
-    :class:`~chess.syzygy.Tablebases`.
+    Opens a collection of tables for probing. See
+    :class:`~chess.syzygy.Tablebase`.
 
     .. note::
 
@@ -1930,9 +1924,13 @@ def open_tablebases(directory, load_wdl=True, load_dtz=True, max_fds=128, Varian
         material composition, **as well as** tablebase files with less pieces.
         This is important because 6-piece and 5-piece files are often
         distributed seperately, but are both required for 6-piece positions.
-        Use :func:`~chess.syzygy.Tablebases.open_directory()` to load
-        tablebases from additional directories.
+        Use :func:`~chess.syzygy.Tablebase.add_directory()` to load
+        tables from additional directories.
     """
-    tables = Tablebases(max_fds=max_fds, VariantBoard=VariantBoard)
-    tables.open_directory(directory, load_wdl=load_wdl, load_dtz=load_dtz)
+    tables = Tablebase(max_fds=max_fds, VariantBoard=VariantBoard)
+    tables.add_directory(directory, load_wdl=load_wdl, load_dtz=load_dtz)
     return tables
+
+# TODO: Deprecated
+open_tablebases = open_tablebase
+Tablebases = Tablebase
